'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _tslib = require('./_tslib-f635d183.js');
var fs = require('fs');
var archiver = require('archiver');
var kleur = require('kleur');
var trimEnd = require('./trimEnd-6fe615e8.js');
var _baseTrim = require('./_baseTrim-8b84a83c.js');
var echo = require('./echo.js');
var getBasename = require('./getBasename.js');
var getDirname = require('./getDirname.js');
var glob = require('./glob.js');
var normalizePath = require('./normalizePath.js');
var toArray$1 = require('./toArray.js');
var toString$1 = require('./toString.js');
var wrapList = require('./wrapList.js');
require('./home.js');
require('os');
require('./root.js');
require('./getType.js');
require('./getName.js');
require('path');
require('fast-glob');

var baseIndexOf = trimEnd._baseIndexOf;

/**
 * Used by `_.trim` and `_.trimStart` to get the index of the first string symbol
 * that is not found in the character symbols.
 *
 * @private
 * @param {Array} strSymbols The string symbols to inspect.
 * @param {Array} chrSymbols The character symbols to find.
 * @returns {number} Returns the index of the first unmatched string symbol.
 */
function charsStartIndex$1(strSymbols, chrSymbols) {
  var index = -1,
      length = strSymbols.length;

  while (++index < length && baseIndexOf(chrSymbols, strSymbols[index], 0) > -1) {}
  return index;
}

var _charsStartIndex = charsStartIndex$1;

var baseToString = trimEnd._baseToString,
    baseTrim = _baseTrim._baseTrim,
    castSlice = trimEnd._castSlice,
    charsEndIndex = trimEnd._charsEndIndex,
    charsStartIndex = _charsStartIndex,
    stringToArray = trimEnd._stringToArray,
    toString = trimEnd.toString_1;

/**
 * Removes leading and trailing whitespace or specified characters from `string`.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to trim.
 * @param {string} [chars=whitespace] The characters to trim.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {string} Returns the trimmed string.
 * @example
 *
 * _.trim('  abc  ');
 * // => 'abc'
 *
 * _.trim('-_-abc-_-', '_-');
 * // => 'abc'
 *
 * _.map(['  foo  ', '  bar  '], _.trim);
 * // => ['foo', 'bar']
 */
function trim(string, chars, guard) {
  string = toString(string);
  if (string && (guard || chars === undefined)) {
    return baseTrim(string);
  }
  if (!string || !(chars = baseToString(chars))) {
    return string;
  }
  var strSymbols = stringToArray(string),
      chrSymbols = stringToArray(chars),
      start = charsStartIndex(strSymbols, chrSymbols),
      end = charsEndIndex(strSymbols, chrSymbols) + 1;

  return castSlice(strSymbols, start, end).join('');
}

var trim_1 = trim;

var trim$1 = /*@__PURE__*/trimEnd.getDefaultExportFromCjs(trim_1);

var execute = function (listSource, target, option) { return _tslib.__awaiter(void 0, void 0, void 0, function () {
    var base, filename, listResource;
    return _tslib.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                base = option.base, filename = option.filename;
                return [4, glob.default(listSource)];
            case 1:
                listResource = _a.sent();
                return [4, new Promise(function (resolve) {
                        var output = fs.createWriteStream("".concat(target, "/").concat(filename));
                        var archive = archiver('zip', {
                            zlib: {
                                level: 9,
                            },
                        });
                        var message = '';
                        archive.on('end', function () { return resolve(true); });
                        archive.on('entry', function (e) { return (message = echo.renderPath("".concat(e.name))); });
                        archive.on('error', function (e) {
                            console.log(kleur.red(e.message));
                            throw e;
                        });
                        archive.on('progress', function (e) {
                            if (!message)
                                return;
                            var gray = kleur.gray("".concat(Math.round((e.fs.processedBytes * 100) / e.fs.totalBytes), "%"));
                            var magenta = kleur.magenta(message);
                            console.log("".concat(gray, " ").concat(magenta));
                            message = '';
                        });
                        archive.on('warning', function (e) {
                            console.log(kleur.red(e.message));
                            throw e;
                        });
                        archive.pipe(output);
                        for (var _i = 0, listResource_1 = listResource; _i < listResource_1.length; _i++) {
                            var src = listResource_1[_i];
                            var name_1 = src.replace(base, '');
                            archive.file(src, { name: name_1 });
                        }
                        archive.finalize();
                    })];
            case 2:
                _a.sent();
                return [2];
        }
    });
}); };
var toArray = function (source, target, option) {
    var _a, _b;
    var listSource = toArray$1.default(source).map(normalizePath.default);
    var pathTarget = normalizePath.default(target || getDirname.default(listSource[0]).replace(/\*/g, ''));
    var _c = typeof option === 'string'
        ? ['', option]
        : [(_a = option.base) !== null && _a !== void 0 ? _a : '', (_b = option.filename) !== null && _b !== void 0 ? _b : ''], base = _c[0], filename = _c[1];
    base = normalizePath.default(base || getBase(listSource));
    if (!filename)
        filename = "".concat(getBasename.default(pathTarget), ".zip");
    return [
        listSource,
        pathTarget,
        {
            base: base,
            filename: filename,
        },
    ];
};
var getBase = function (listSource) {
    var source = listSource[0];
    if (source.includes('*'))
        return trim$1(source.replace(/\*.*/u, ''), '/');
    return getDirname.default(source);
};
var main = function (source, target, option) {
    if (target === void 0) { target = ''; }
    if (option === void 0) { option = ''; }
    return _tslib.__awaiter(void 0, void 0, void 0, function () {
        return _tslib.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, execute.apply(void 0, toArray(source, target, option))];
                case 1:
                    _a.sent();
                    echo.default('zip', "zipped ".concat(wrapList.default(source), " to '").concat(target, "', as '").concat(toString$1.default(option), "'"));
                    return [2];
            }
        });
    });
};

exports.default = main;
